@@ -1,7 +1,7 @@
 package Dancer::Test;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Test helpers to test a Dancer application
-$Dancer::Test::VERSION = '1.3511'; # TRIAL
+$Dancer::Test::VERSION = '1.3514'; # TRIAL
 # test helpers for Dancer apps
 
 use strict;
@@ -351,7 +351,8 @@ sub dancer_response {
                 if ( $file->{data} ) {
                     $content .= $file->{data};
                 } else {
-                    open my $fh, '<', $file->{filename};
+                    open my $fh, '<', $file->{filename}
+                        or die "Failed to open $file->{filename} - $!";
                     if ( -B $file->{filename} ) {
                         binmode $fh;
                     }
@@ -468,7 +469,7 @@ Dancer::Test - Test helpers to test a Dancer application
 
 =head1 VERSION
 
-version 1.3511
+version 1.3514
 
 =head1 SYNOPSIS
 
